searchData={"items":[{"type":"module","title":"JsonXema","doc":"A [JSON Schema](http://json-schema.org) validator.","ref":"JsonXema.html"},{"type":"function","title":"JsonXema.new/2","doc":"This function creates a new `JsonXema` from the given `schema`.\n\nPossible options:\n+ `:loader` - a loader for remote schemas. This option will overwrite the\n  loader from the config. See [Configure a loader](loader.html) to how to\n  define a loader.","ref":"JsonXema.html#new/2"},{"type":"function","title":"Examples - JsonXema.new/2","doc":"iex> ~s({\"type\": \"string\"})\n    ...> |> Jason.decode!()\n    ...> |> JsonXema.new()\n    %JsonXema{refs: %{}, schema: %Xema.Schema{type: :string}}","ref":"JsonXema.html#new/2-examples"},{"type":"function","title":"JsonXema.to_xema/1","doc":"Converts `%JsonXema{}` to `%Xema{}`.","ref":"JsonXema.html#to_xema/1"},{"type":"function","title":"JsonXema.valid?/2","doc":"Returns `true` if the `value` is a valid value against the given `schema`;\notherwise returns `false`.","ref":"JsonXema.html#valid?/2"},{"type":"function","title":"JsonXema.validate/3","doc":"Returns `:ok` if the `value` is a valid value against the given `schema`;\notherwise returns an error tuple.\n\nWith the option `:fail`, you can define when the validation is aborted. This\nalso influences how many error reasons are returned.\n- `:immediately` aborts the validation when the first validation fails.\n- `:early` (default) aborts on failed validations, but runs validations\n  for all properties and items.\n- `:finally` aborts after all possible validations.","ref":"JsonXema.html#validate/3"},{"type":"function","title":"JsonXema.validate!/3","doc":"Returns `:ok` if the `value` is a valid value against the given `schema`;\notherwise raises a `Elixir.JsonXema.ValidationError`. See `validate3` for\navailable options.","ref":"JsonXema.html#validate!/3"},{"type":"type","title":"JsonXema.result/0","doc":"The return type of a validation run.","ref":"JsonXema.html#t:result/0"},{"type":"type","title":"JsonXema.schema/0","doc":"","ref":"JsonXema.html#t:schema/0"},{"type":"type","title":"JsonXema.t/0","doc":"This struct contains the schema and references of the schema.","ref":"JsonXema.html#t:t/0"},{"type":"exception","title":"JsonXema.SchemaError","doc":"Raised when a schema can't be build.","ref":"JsonXema.SchemaError.html"},{"type":"exception","title":"JsonXema.ValidationError","doc":"Raised when a validation fails.","ref":"JsonXema.ValidationError.html"},{"type":"exception","title":"Example - JsonXema.ValidationError","doc":"iex> schema = JsonXema.new(%{\"type\" => \"string\"})\n    iex> {:error, error} = JsonXema.validate(schema, 6)\n    iex> Exception.message(error)\n    ~s|Expected \"string\", got 6.|","ref":"JsonXema.ValidationError.html#module-example"},{"type":"function","title":"JsonXema.ValidationError.format_error/1","doc":"This function returns an error message for an error or error tuple.","ref":"JsonXema.ValidationError.html#format_error/1"},{"type":"function","title":"Example - JsonXema.ValidationError.format_error/1","doc":"iex> schema = JsonXema.new(%{\"type\" => \"integer\"})\n    iex> schema\n    ...>   |> JsonXema.validate(1.1)\n    ...>   |> JsonXema.ValidationError.format_error()\n    ~s|Expected \"integer\", got 1.1.|","ref":"JsonXema.ValidationError.html#format_error/1-example"},{"type":"function","title":"JsonXema.ValidationError.travers_errors/4","doc":"Traverse the error tree and invokes the given function.","ref":"JsonXema.ValidationError.html#travers_errors/4"},{"type":"function","title":"Example - JsonXema.ValidationError.travers_errors/4","doc":"iex> fun = fn _error, path, acc ->\n    ...>   [\"Error at \" <> inspect(path) | acc]\n    ...> end\n    iex>\n    iex> schema = JsonXema.new(%{\n    ...>   \"properties\" => %{\n    ...>     \"int\" => %{\"type\" => \"integer\"},\n    ...>     \"names\" => %{\n    ...>       \"type\" => \"array\",\n    ...>       \"items\" => %{\"type\" => \"string\"}\n    ...>     },\n    ...>     \"num\" => %{\"anyOf\" => [\n    ...>       %{\"type\" => \"integer\"},\n    ...>       %{\"type\" => \"number\"}\n    ...>     ]}\n    ...>   }\n    ...> })\n    iex>\n    iex> data = %{\"int\" => \"x\", \"names\" => [1, \"x\", 5], \"num\" => :foo}\n    iex>\n    iex> schema\n    ...>   |> JsonXema.validate(data)\n    ...>   |> JsonXema.ValidationError.travers_errors([], fun)\n    [\n      ~s|Error at [\"num\"]|,\n      ~s|Error at [\"names\", 2]|,\n      ~s|Error at [\"names\", 0]|,\n      ~s|Error at [\"names\"]|,\n      ~s|Error at [\"int\"]|,\n      ~s|Error at []|\n    ]","ref":"JsonXema.ValidationError.html#travers_errors/4-example"},{"type":"type","title":"JsonXema.ValidationError.opts/0","doc":"","ref":"JsonXema.ValidationError.html#t:opts/0"},{"type":"type","title":"JsonXema.ValidationError.path/0","doc":"","ref":"JsonXema.ValidationError.html#t:path/0"},{"type":"extras","title":"JsonXema","doc":"# JsonXema\n\nJsonXema is a [JSON Schema](http://json-schema.org) validator with support\nfor draft 04, 06, and 07.\n\nJsonXema based on elixir schema validator\n[Xema](https://github.com/hrzndhrn/xema).\n\nJsonXema is in early beta. If you try it and has an issue, report them.","ref":"readme.html"},{"type":"extras","title":"Usage","doc":"# Usage\n\nA JSON parser is required to create a schema from JSON. It is also possible to\ncreate a schema directly from an elixir data structure. There are three functions available to validate data against a schema.\n+ `JsonXema.valid?/2` gets a schema and any data and returns `true` for valid\n  data and `false` otherwise.\n+ `JsonXema.validate/2` gets a schema and any data and returns `:ok` for valid\n  data and an error tuple otherwise.\n+ `JsonXema.validate!/2` gets a schema and any data and returns `:ok` for valid\n  data and raised an exception otherwise.\n\n```elixir\niex> schema = \"\"\"\n...> {\n...>   \"type\": \"object\",\n...>   \"properties\": {\n...>     \"name\": {\n...>       \"type\": \"string\",\n...>       \"min_length\": 3\n...>     },\n...>     \"age\": {\n...>       \"type\": \"integer\",\n...>       \"minimum\": 0\n...>     }\n...>   },\n...>   \"additionalProperties\": false\n...> }\n...> \"\"\"\n...> |> Jason.decode!()\n...> |> JsonXema.new()\n...>\n...> data = Jason.decode!(\"\"\"\n...>   {\"name\": \"John\", \"age\": 42}\n...> \"\"\")\n...> JsonXema.valid?(schema, data)\ntrue\n...> JsonXema.valid?(schema, %{\"name\" => \"Peter\", \"age\" => -55})\nfalse\n...> JsonXema.valid?(schema, %{\"name\" => \"Peter\", \"old\" => 55})\nfalse\n...> JsonXema.validate(schema, %{\"name\" => \"Peter\", \"age\" => -55})\n{:error, %JsonXema.ValidationError{\n  reason: %{properties: %{\"age\" => %{minimum: 0, value: -55}}}}}\n...> JsonXema.validate(schema, %{\"name\" => \"Peter\", \"old\" => 55})\n{:error, %JsonXema.ValidationError{\n  reason: %{properties: %{\"old\" => %{additionalProperties: false}}}}}\n```","ref":"usage.html"},{"type":"extras","title":"Configure a loader","doc":"# Configure a loader\n\nA loader returns the data for a remote schema. The remote schemas are defined\nin a schema like this.\n\n```json\n...\n  \"properties\": {\n    \"int\": {\"$ref\": \"http://localhost:1234/int.json\"}\n  }\n...\n```\n\nA loader will be configured like this.\n\n```elixir\nconfig :xema, loader: My.Loader\n```\n\nA loader is a module which use the behaviour `Xema.Loader`.\n\n```elixir\ndefmodule My.Loader do\n  @moduledoc false\n\n  @behaviour Xema.Loader\n\n  @spec fetch(URI.t()) :: {:ok, any} | {:error, any}\n  def fetch(uri) do\n    case HTTPoison.get(uri) do\n      {:ok, %HTTPoison.Response{status_code: 200, body: body}} ->\n        {:ok, Jason.decode!(body)}\n\n      {:ok, %HTTPoison.Response{status_code: 404}} ->\n        {:error, \"Remote schema '#{uri}' not found.\"}\n\n      {:ok, %HTTPoison.Response{status_code: code}} ->\n        {:error, \"HTTP Error - code: #{code}\"}\n\n      {:error, reason} ->\n        {:error, reason}\n    end\n  end\nend\n```\n\nThe function `fetch/1` will be called by `Xema` and expects an `%URI{}`. The\nreturn value must be a tuple of `:ok` and the required data for a schema or an\nerror tuple.","ref":"loader.html"},{"type":"extras","title":"File loader - Configure a loader","doc":"A loader to read schema from the local file system.\n\nIn the schema:\n```elixir\n...\n  \"properties\": {\n    \"int\": {\"$ref\": \"integer.json\"}\n  }\n...\n```\n\nThe loader:\n```elixir\ndefmodule My.Loader do\n  @moduledoc false\n\n  @behaviour Xema.Loader\n\n  @impl Xema.Loader\n  def fetch(uri) do\n    \"path/to/schemas\"\n    |> Path.join(uri.path)\n    |> File.read!()\n    |> Jason.decode()\n  end\nend\n```","ref":"loader.html#file-loader"},{"type":"extras","title":"Unsupported","doc":"# Unsupported\n\nSome of the optional JSON-Schema features are not supported by JsonXema.","ref":"unsupported.html"},{"type":"extras","title":"Unsupported semantic validation - Unsupported","doc":"For now, the keyword `format` do not support the following formats:\n+ `idn-email` the I18N equivalent of `email`\n+ `idn-hostname` I18N equivalent of `hostname`\n+ `iri` the I18N equivalent of `uri`\n+ `iri-reference` the I18N equivalent of `uri-reference`","ref":"unsupported.html#unsupported-semantic-validation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}